@@ -1,23 +1,23 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
-# Copyright (c) 2014-2020 Adam.Dybbroe
-
+#
+# Copyright (c) 2014-2020 Pytroll developers
+#
 # Author(s):
-
+#
 #   Adam.Dybbroe <adam.dybbroe@smhi.se>
 #   Panu Lahtinen <panu.lahtinen@fmi.fi>
-
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-
+#
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -167,12 +167,12 @@ class RadTbConverter(object):
 
     def _getsatname(self):
         """Get the satellite name used in the rsr-reader, from the platform and number."""
-        if self.platform_name.startswith("Meteosat"):
-            return self.platform_name
-        else:
+        if not self.platform_name.startswith("Meteosat"):
             raise NotImplementedError(
                 'Platform {0} not yet supported...'.format(self.platform_name))
 
+        return self.platform_name
+
     @staticmethod
     def _getitem(block, lut):
         """Index the lut, numpy style."""
@@ -297,7 +297,7 @@ class SeviriRadTbConverter(RadTbConverter):
 
     def _get_rsr(self):
         """Overload the _get_rsr method, since RSR data are ignored here."""
-        pass
+        LOG.debug("RSR data are ignored in this converter!")
 
     def radiance2tb(self, rad):
         """Get the Tb from the radiance using the simple non-linear regression method.
